@@ -1,13 +1,12 @@
 module ChildProcess
   module Windows
     class ProcessBuilder
-      attr_accessor :inherit, :detach, :duplex, :environment, :stdout, :stderr, :cwd
+      attr_accessor :detach, :duplex, :environment, :stdout, :stderr, :cwd
       attr_reader :stdin
 
       def initialize(args)
         @args        = args
 
-        @inherit     = false
         @detach      = false
         @duplex      = false
         @environment = nil
@@ -18,6 +17,7 @@ module ChildProcess
         @stdin       = nil
 
         @flags       = 0
+        @job_ptr     = nil
         @cmd_ptr     = nil
         @env_ptr     = nil
         @cwd_ptr     = nil
@@ -28,7 +28,7 @@ module ChildProcess
         create_environment_pointer
         create_cwd_pointer
 
-        setup_detach
+        setup_flags
         setup_io
 
         pid = create_process
@@ -76,7 +76,7 @@ module ChildProcess
           @cmd_ptr,     # command line
           nil,          # process attributes
           nil,          # thread attributes
-          @inherit,     # inherit handles
+          true,         # inherit handles
           @flags,       # creation flags
           @env_ptr,     # environment
           @cwd_ptr,     # current directory
@@ -97,45 +97,41 @@ module ChildProcess
         @process_info ||= ProcessInfo.new
       end
 
-      def setup_detach
+      def setup_flags
         @flags |= DETACHED_PROCESS if @detach
+        @flags |= CREATE_BREAKAWAY_FROM_JOB
       end
 
       def setup_io
-        if @stdout || @stderr
-          startup_info[:dwFlags] ||= 0
-          startup_info[:dwFlags] |= STARTF_USESTDHANDLES
+        startup_info[:dwFlags] ||= 0
+        startup_info[:dwFlags] |= STARTF_USESTDHANDLES
 
-          @inherit = true
-
-          if @stdout
-            startup_info[:hStdOutput] = std_stream_handle_for(@stdout)
-          end
-
-          if @stderr
-            startup_info[:hStdError] = std_stream_handle_for(@stderr)
-          end
+        if @stdout
+          startup_info[:hStdOutput] = std_stream_handle_for(@stdout)
         end
 
-        setup_stdin if @duplex
-      end
+        if @stderr
+          startup_info[:hStdError] = std_stream_handle_for(@stderr)
+        end
 
-      def setup_stdin
-        read_pipe_ptr  = FFI::MemoryPointer.new(:pointer)
-        write_pipe_ptr = FFI::MemoryPointer.new(:pointer)
-        sa             = SecurityAttributes.new(:inherit => true)
+        if @duplex
+          read_pipe_ptr  = FFI::MemoryPointer.new(:pointer)
+          write_pipe_ptr = FFI::MemoryPointer.new(:pointer)
+          sa             = SecurityAttributes.new(:inherit => true)
 
-        ok = Lib.create_pipe(read_pipe_ptr, write_pipe_ptr, sa, 0)
-        Lib.check_error ok
+          ok = Lib.create_pipe(read_pipe_ptr, write_pipe_ptr, sa, 0)
+          Lib.check_error ok
 
-        @read_pipe  = read_pipe_ptr.read_pointer
-        @write_pipe = write_pipe_ptr.read_pointer
+          @read_pipe  = read_pipe_ptr.read_pointer
+          @write_pipe = write_pipe_ptr.read_pointer
 
-        @inherit = true
-        Lib.set_handle_inheritance @read_pipe, true
-        Lib.set_handle_inheritance @write_pipe, false
+          Lib.set_handle_inheritance @read_pipe, true
+          Lib.set_handle_inheritance @write_pipe, false
 
-        startup_info[:hStdInput] = @read_pipe
+          startup_info[:hStdInput] = @read_pipe
+        else
+          startup_info[:hStdInput] = std_stream_handle_for(STDIN)
+        end
       end
 
       def std_stream_handle_for(io)
